@@ -1071,6 +1071,12 @@ class DSLibrary(object):
                 f_tmp.flush()
                 return read_method(f_tmp.name, **read_args)
         try:
+            if format == "json" and read_args and not read_args.get("lines") and read_args.get("nrows"):
+                # nrows can't be honored except in 'lines' mode - fake it (not efficient, but produces same results)
+                read_args = dict(read_args)
+                nrows = read_args.pop("nrows")
+                out = read_method(f_r, **read_args)
+                return out.head(nrows)
             return read_method(f_r, **read_args)
         except UnicodeDecodeError as err:
             raise DSLibraryDataFormatException(
