@@ -1,5 +1,6 @@
 import unittest
 import pandas
+import mock
 
 from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2, \
     connect_to_database
@@ -65,3 +66,15 @@ class TestConnect(unittest.TestCase):
         self.assertEqual(strategy.open_args, {'dsn': 'dbname=database host=host password=p port=1234 user=u'})
         import psycopg2
         self.assertIs(strategy.opener, psycopg2.connect)
+
+    def test_pg_2(self):
+        import dslibrary
+        class MyPg(object):
+            def set_isolation_level(self, n):
+                pass
+        def conn(**kwargs):
+            self.assertEqual(kwargs, {'dsn': 'dbname=postgres host=HOST password=xyz port=5432 user=postgres'})
+            return MyPg()
+        with mock.patch("psycopg2.connect", conn):
+            c = dslibrary.get_sql_connection('postgres://HOST:5432/postgres', password="xyz", **{'username': 'postgres'})
+            assert isinstance(c, MyPg)
